fnss.topologies.topology.Topology.selfloop_edges — FNSS 0.5.0 documentation

### Navigation

- index
- modules |
- modules |
- FNSS 0.5.0 documentation »

# fnss.topologies.topology.Topology.selfloop_edges

`Topology.` `selfloop_edges`(data=False)

  Return a list of selfloop edges.

  A selfloop edge has the same node at both ends.

  Parameters : | data : bool, optional (default=False) Return selfloop edges as two tuples (u,v) (data=False) or three-tuples (u,v,data) (data=True)
  Returns : | edgelist : list of edge tuples A list of all selfloop edges.

  See also

  `nodes_with_selfloops`, `number_of_selfloops`

  Examples

      >>> G = nx.Graph()   # or DiGraph, MultiGraph, MultiDiGraph, etc
      >>> G.add_edge(1,1)
      >>> G.add_edge(1,2)
      >>> G.selfloop_edges()
      [(1, 1)]
      >>> G.selfloop_edges(data=True)
      [(1, 1, {})]

### Navigation

- index
- modules |
- modules |
- FNSS 0.5.0 documentation »